@@ -36,7 +36,7 @@
 #' # Use kd from experimental data (recommended):
 #' define_water(ph = 7.5, temp = 25) %>%
 #'   solvect_o3(time = 10, dose = 2, kd = -0.5, baffle = 0.9)
-# Use modeled decay curve:
+#' # Use modeled decay curve:
 #' define_water(ph = 7.5, alk = 100, doc = 2, uv254 = .02, br = 50) %>%
 #'   solvect_o3(time = 10, dose = 2, baffle = 0.5)
 #'
@@ -51,13 +51,26 @@ solvect_o3 <- function(water, time, dose, kd, baffle) {
 
   if (!missing(kd)) {
     if (!is.na(kd)) {
-      use_kd <- TRUE
+      if (kd < 0) {
+        use_kd <- TRUE
+      } else {
+        use_kd <- FALSE
+        stop("kd must be less than zero for decay curve")
+      }
     } else {
       use_kd <- FALSE
     }
   } else {
     use_kd <- FALSE
   }
+
+  if (dose == 0) {
+    tibble(
+      "ct_actual" = 0, "glog_removal" = 0, "vlog_removal" = 0,
+      "clog_removal" = 0
+    )
+  }
+
   # First order decay curve: y = dose * exp(k*t)
   # Integral from 0 to t of curve above: dose * (exp(kt) - 1) / k
   if (use_kd) {
@@ -91,7 +104,7 @@ solvect_o3 <- function(water, time, dose, kd, baffle) {
 
 #' @rdname solvect_o3
 #'
-#' @param df a data frame containing a water class column, which has already been computed using [define_water_chain()]
+#' @param df a data frame containing a water class column, which has already been computed using [define_water_chain()].
 #' @param input_water name of the column of Water class data to be used as the input for this function. Default is "defined_water".
 #' @param water_prefix name of the input water used for the calculation will be appended to the start of output columns. Default is TRUE.
 #'
