@@ -68,6 +68,20 @@ test_that("chemdose_dbp works.", {
   expect_equal(round(water6@haa5), 12)
 })
 
+test_that("users can provide their own dbp coefficients.", {
+  coeff <- data.frame(A = 5E-2, a = 1, b = .5, c = .5, d = .5, e = 1, f = .5, ph_const = 7.5, ID = "chcl3")
+
+  water1 <- suppressWarnings(define_water(ph = 7.5, temp = 20, toc = 3.5, uv254 = 0.1, br = 50)) %>%
+    chemdose_dbp(cl2 = 2, time = 8)
+
+  water2 <- suppressWarnings(define_water(ph = 7.5, temp = 20, toc = 3.5, uv254 = 0.1, br = 50)) %>%
+    chemdose_dbp(cl2 = 2, time = 8, coeff = coeff)
+
+  expect_true(water1@tthm == water2@tthm) # did not use custom coeff for tthm
+  expect_false(water1@chcl3 == water2@chcl3)
+  expect_equal(round(water2@chcl3, 2), 58.78)
+})
+
 ################################################################################*
 ################################################################################*
 # chemdose_dbp helpers ----
@@ -187,7 +201,7 @@ test_that("chemdose_dbp_chain can use a column or function argument for chemical
   expect_equal(water1$disinfected_water_haa5, water2$disinfected_water_haa5)
   expect_equal(water1$disinfected_water_mbaa, water2$disinfected_water_mbaa)
 
-  # Test that inputting time/cl2 separately (in column and as an argument)  gives save results
+  # Test that inputting time/cl2 separately (in column and as an argument)  gives same results
   expect_equal(water1$disinfected_water_tthm, water3$disinfected_water_tthm)
   expect_equal(water2$disinfected_water_haa5, water3$disinfected_water_haa5)
   expect_equal(water2$disinfected_water_mbaa, water3$disinfected_water_mbaa)
@@ -237,46 +251,87 @@ test_that("chemdose_dbp_chain correctly handles arguments with multiple numbers"
   expect_equal(nrow(water) * 3, nrow(water2))
 })
 
-# test_that("chemdose_dbp_once outputs are the same as base function, chemdose_dbp", {
-#   water1 <- suppressWarnings(define_water(7.9, 20, 50,
-#     tot_hard = 50, ca = 13,
-#     na = 20, k = 20, cl = 30, so4 = 20,
-#     tds = 200, cond = 100,
-#     toc = 2, doc = 1.8, uv254 = 0.05, br = 50
-#   )) %>%
-#     chemdose_dbp(cl2 = 10, time = 8)
-#
-#   water2 <- suppressWarnings(water_df %>%
-#     slice(1) %>%
-#     mutate(br = 50) %>%
-#     define_water_chain() %>%
-#     chemdose_dbp_once(cl2 = 10, time = 8))
-#
-#   expect_equal(water1@chcl3, water2$chcl3)
-#   expect_equal(water1@chcl2br, water2$chcl2br)
-#   expect_equal(water1@chbr2cl, water2$chbr2cl)
-#   expect_equal(water1@chbr3, water2$chbr3)
-#   expect_equal(water1@tthm, water2$tthm)
-#   expect_equal(water1@mcaa, water2$mcaa)
-#   expect_equal(water1@dcaa, water2$dcaa)
-#   expect_equal(water1@tcaa, water2$tcaa)
-#   expect_equal(water1@mbaa, water2$mbaa)
-#   expect_equal(water1@dbaa, water2$dbaa)
-#   expect_equal(water1@haa5, water2$haa5)
-# })
-#
-# # Check that output is a data frame
-#
-# test_that("chemdose_dbp_once is a data frame", {
-#   water1 <- suppressWarnings(water_df %>%
-#     slice(1) %>%
-#     mutate(br = 50) %>%
-#     define_water_chain() %>%
-#     balance_ions_chain() %>%
-#     chemdose_dbp_once(
-#       input_water = "balanced_water",
-#       cl2 = 5, time = 100
-#     ))
-#
-#   expect_true(is.data.frame(water1))
-# })
+test_that("users can provide their own dbp coefficients to chemdose_dbp_chain.", {
+  coeff <- data.frame(A = 5E-2, a = 1, b = .5, c = .5, d = .5, e = 1, f = .5, ph_const = 7.5, ID = "chcl3")
+
+  water1 <- water_df %>%
+    mutate(br = 80) %>%
+    define_water_chain() %>%
+    chemdose_dbp_chain("defined_water", cl2 = 2, time = 120) %>%
+    pluck_water("disinfected_water", c("tthm", "chcl3"))
+
+  water2 <- water_df %>%
+    mutate(br = 80) %>%
+    define_water_chain() %>%
+    chemdose_dbp_chain("defined_water", cl2 = 2, time = 120, coeff = coeff) %>%
+    pluck_water("disinfected_water", c("tthm", "chcl3"))
+
+  expect_equal(water1$disinfected_water_tthm, water2$disinfected_water_tthm) # no custom coeff inputted for tthm
+  expect_false(identical(water1$disinfected_water_chcl3, water2$disinfected_water_chcl3))
+  expect_false(any(is.na(water2$disinfected_water_chcl3)) || identical(water2$disinfected_water_chcl3, 0))
+})
+
+test_that("chemdose_dbp_once outputs are the same as base function, chemdose_dbp", {
+  testthat::skip_on_cran()
+  water1 <- suppressWarnings(define_water(7.9, 20, 50,
+    tot_hard = 50, ca = 13,
+    na = 20, k = 20, cl = 30, so4 = 20,
+    tds = 200, cond = 100,
+    toc = 2, doc = 1.8, uv254 = 0.05, br = 50
+  )) %>%
+    chemdose_dbp(cl2 = 10, time = 8)
+
+  water2 <- suppressWarnings(water_df %>%
+    slice(1) %>%
+    mutate(br = 50) %>%
+    define_water_chain() %>%
+    chemdose_dbp_once(cl2 = 10, time = 8))
+
+  expect_equal(water1@chcl3, water2$defined_water_chcl3)
+  expect_equal(water1@chcl2br, water2$defined_water_chcl2br)
+  expect_equal(water1@chbr2cl, water2$defined_water_chbr2cl)
+  expect_equal(water1@chbr3, water2$defined_water_chbr3)
+  expect_equal(water1@tthm, water2$defined_water_tthm)
+  expect_equal(water1@mcaa, water2$defined_water_mcaa)
+  expect_equal(water1@dcaa, water2$defined_water_dcaa)
+  expect_equal(water1@tcaa, water2$defined_water_tcaa)
+  expect_equal(water1@mbaa, water2$defined_water_mbaa)
+  expect_equal(water1@dbaa, water2$defined_water_dbaa)
+  expect_equal(water1@haa5, water2$defined_water_haa5)
+})
+
+# Check that output is a data frame
+
+test_that("chemdose_dbp_once is a data frame", {
+  testthat::skip_on_cran()
+  water1 <- suppressWarnings(water_df %>%
+    slice(1) %>%
+    mutate(br = 50) %>%
+    define_water_chain() %>%
+    balance_ions_chain() %>%
+    chemdose_dbp_once(
+      input_water = "balanced_water",
+      cl2 = 5, time = 100
+    ))
+
+  expect_true(is.data.frame(water1))
+})
+
+# check that chemdose_dbp_once works when water_prefix is false
+test_that("chemdose_dbp_once works when water_prefix is false", {
+  testthat::skip_on_cran()
+  water1 <- suppressWarnings(water_df %>%
+    slice(1) %>%
+    mutate(br = 50) %>%
+    define_water_chain() %>%
+    chemdose_dbp_once(cl2 = 10, time = 8))
+
+  water2 <- suppressWarnings(water_df %>%
+    slice(1) %>%
+    mutate(br = 50) %>%
+    define_water_chain() %>%
+    chemdose_dbp_once(cl2 = 10, time = 8, water_prefix = FALSE))
+
+  expect_equal(water1$defined_water_tthm, water2$tthm)
+  expect_equal(water1$defined_water_haa5, water2$haa5)
+})
