@@ -140,7 +140,7 @@ test_that("define_water correctly specifies when estimates are used.", {
 test_that("define_water correctly calculates dic", {
   water1 <- suppressWarnings(define_water(ph = 7, temp = 25, alk = 100))
 
-  dic_mg <- calculate_dic(water1)
+  dic_mg <- water1@tot_co3 * tidywater::mweights$dic * 1000
   expect_equal(dic_mg, water1@dic)
 })
 
@@ -228,11 +228,12 @@ test_that("define_water_chain correctly calculates dic", {
     pluck_water(parameter = "dic") %>%
     slice(1)
 
-  dic_mol <- suppressWarnings(define_water(
+  water2 <- define_water(
     ph = 7.9, temp = 20, alk = 50, tot_hard = 50, na = 20, k = 20,
     cl = 30, so4 = 20, tds = 200, cond = 100, toc = 2, doc = 1.8, uv254 = 0.05
-  )) %>%
-    calculate_dic()
+  )
+  dic_mol <- water2@tot_co3 * tidywater::mweights$dic * 1000
+
 
   expect_equal(dic_mol, water1$defined_water_dic)
 })
