@@ -73,29 +73,6 @@ test_that("Calcium hardness calculation works.", {
   expect_equal(calculate_hardness(.002, 0, startunit = "M", type = "ca"), .002 * mweights$caco3 * 1000)
 })
 
-# calculate_dic----
-test_that("calculate _dic doesn't work without ph or alkalinity.", {
-  water1 <- suppressWarnings(define_water(ph = 7)) %>%
-    calculate_dic()
-  water2 <- suppressWarnings(define_water(alk = 70)) %>%
-    calculate_dic()
-
-  expect_equal(water1, NA_real_)
-  expect_equal(water2, NA_real_)
-})
-
-test_that("calculate _dic works.", {
-  water1 <- suppressWarnings(define_water(ph = 7, alk = 200)) %>%
-    calculate_dic()
-
-  water2 <- suppressWarnings(define_water(ph = 6.5, alk = 5)) %>%
-    calculate_dic()
-
-  expect_equal(round(water1), 59)
-  expect_equal(round(water2), 2)
-})
-
-
 # Calculate alpha carbonate ----
 
 test_that("Carbonate alpha calculations work.", {
